@@ -25,7 +25,7 @@ use std::thread;
 use std::thread::{sleep, JoinHandle};
 use std::time::{Duration, Instant};
 use tui::backend::{Backend, CrosstermBackend};
-use tui::layout::{Constraint, Direction, Layout};
+use tui::layout::{Constraint, Direction, Flex, Layout};
 use tui::style::{Color, Style};
 use tui::text::Span;
 use tui::widgets::{Axis, Block, Borders, Chart, Dataset};
@@ -189,12 +189,12 @@ impl App {
     }
 
     fn x_axis_labels(&self, bounds: [f64; 2]) -> Vec<Span> {
-        let lower_utc = NaiveDateTime::from_timestamp_opt(bounds[0] as i64, 0)
+        let lower_utc = DateTime::<Utc>::from_timestamp(bounds[0] as i64, 0)
             .expect("Error parsing x-axis bounds 0");
-        let upper_utc = NaiveDateTime::from_timestamp_opt(bounds[1] as i64, 0)
+        let upper_utc = DateTime::<Utc>::from_timestamp(bounds[1] as i64, 0)
             .expect("Error parsing x-asis bounds 1");
-        let lower = Local::from_utc_datetime(&Local, &lower_utc);
-        let upper = Local::from_utc_datetime(&Local, &upper_utc);
+        let lower: DateTime<Local> = DateTime::from(lower_utc);
+        let upper: DateTime<Local> = DateTime::from(upper_utc);
         let diff = (upper - lower) / 2;
         let midpoint = lower + diff;
         vec![
@@ -480,6 +480,7 @@ fn main() -> Result<()> {
             Event::Render => {
                 terminal.draw(|f| {
                     let chunks = Layout::default()
+                        .flex(Flex::Legacy)
                         .direction(Direction::Vertical)
                         .vertical_margin(args.vertical_margin)
                         .horizontal_margin(args.horizontal_margin)
